@@ -9,7 +9,6 @@ import (
 	"github.com/gopasspw/gopass/internal/out"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/gopasspw/gopass/tests/gptest"
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -33,11 +32,11 @@ func TestSync(t *testing.T) {
 
 	t.Run("default", func(t *testing.T) {
 		defer buf.Reset()
-		assert.NoError(t, act.Sync(gptest.CliCtx(ctx, t)))
+		require.NoError(t, act.Sync(gptest.CliCtx(ctx, t)))
 	})
 
 	t.Run("sync --store=root", func(t *testing.T) {
 		defer buf.Reset()
-		assert.NoError(t, act.Sync(gptest.CliCtxWithFlags(ctx, t, map[string]string{"store": "root"})))
+		require.NoError(t, act.Sync(gptest.CliCtxWithFlags(ctx, t, map[string]string{"store": "root"})))
 	})
 }
