@@ -416,3 +416,40 @@ func TestComputeMoveDestination(t *testing.T) {
 		})
 	}
 }
+
+func TestRegression892(t *testing.T) {
+	u := gptest.NewUnitTester(t)
+	u.Entries = []string{
+		"some/example",
+		"some/example/test2",
+		"communication/t1",
+	}
+	require.NoError(t, u.InitStore(""))
+
+	ctx := context.Background()
+	ctx = ctxutil.WithAlwaysYes(ctx, true)
+	ctx = ctxutil.WithHidden(ctx, true)
+
+	rs, err := createRootStore(ctx, u)
+	require.NoError(t, err)
+	require.NoError(t, rs.Delete(ctx, "foo"))
+
+	// Initial state:
+	entries, err := rs.List(ctx, tree.INF)
+	require.NoError(t, err)
+	require.Equal(t, []string{
+		"communication/t1",
+		"some/example",
+		"some/example/test2",
+	}, entries)
+
+	// -> move comm email => Rename comm to email
+	require.NoError(t, rs.Move(ctx, "some/example", "some/example/test1"))
+	entries, err = rs.List(ctx, tree.INF)
+	require.NoError(t, err)
+	require.Equal(t, []string{
+		"communication/t1",
+		"some/example/test1",
+		"some/example/test2",
+	}, entries)
+}
